/*
 * RonaldBoard example source
 * http://www.ronaldteune.nl/projects/index.php/RonaldBoard
 * License: GPLv2
 * This code does some PWM and ADC over I2C.
 *
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay_basic.h>
#include <util/delay.h>
#include "usiTwiSlave.h"

#define I2C_SLAVE_ADDR  0x26

void adcInit() {

	// Enable ADC2/PB4 as ADC input
	 ADMUX |= 1 << MUX1;

	// Set the ADC clock precaler to 16 (ie 500KHz if the main clock is 8MHz).
	ADCSRA |= 1 << ADPS2;

	// Left align the output (this lets us just use the 8 bits in the ADCH output register (we 
	// can ignore the extra 2 bits in the ADCL register).
	ADMUX |= 1 << ADLAR;

	// Enable ADC.
	ADCSRA |= 1 << ADEN;
}

uint8_t adcRead() {

	// Start a conversion	
	ADCSRA |= 1 << ADSC;

	// Wait for it to finish
	while (ADCSRA & (1 << ADSC));

	// Get the result.
	return ADCH;
}

// Somewhere to store the values the master writes to i2c register 2 and 3.
static volatile uint8_t i2cReg2 = 0;
static volatile uint8_t i2cReg3 = 0;

// A callback triggered when the i2c master attempts to read from a register.
uint8_t i2cReadFromRegister(uint8_t reg)
{
	switch (reg)
	{
		case 0: 
			return OCR1B;
		case 1:
			return adcRead();
		case 2:
			return i2cReg2;
		case 3:
			return i2cReg3;
		case 4:
			return -1;
		case 5:
			return OCR1A;
		default:
			return reg;
	}
}

// A callback triggered when the i2c master attempts to write to a register.
void i2cWriteToRegister(uint8_t reg, uint8_t value)
{
	switch (reg)
	{
		case 2: 
			OCR1B = value;
			i2cReg2 = value;
			break;
		case 3:
			OCR1A = value;
			i2cReg3 = value;
			break;
	}
}

int main()
{
	// Set the LED pin as output.
	DDRB |= (1 << 3) | (1 << 1);
	

	usiTwiSlaveInit(I2C_SLAVE_ADDR, i2cReadFromRegister, i2cWriteToRegister);
	adcInit();
	sei();

TCCR1=0x01; // CS10? PCK = ??
GTCCR=0x60; // must be 0x60 for OCR1B //GTCCR = (1 << PWM1B) | (1 << COM1B1);
TCNT1=0x00;
OCR1A=0x66;
OCR1B=0x22;
OCR1C=0xff; 
TCCR0B |= (1 << CS00) | (1 << CS02);


TCCR1 |= (1 << COM1A1) | (1 << PWM1A);


	while(1);
}
 
